@@ -66,8 +66,6 @@ static int signals[LAST_SIGNAL] = { 0 };
 static void	bluetooth_chooser_button_class_init	(BluetoothChooserButtonClass * klass);
 static void	bluetooth_chooser_button_init		(BluetoothChooserButton      * button);
 
-static GtkButtonClass *parent_class;
-
 G_DEFINE_TYPE(BluetoothChooserButton, bluetooth_chooser_button, GTK_TYPE_BUTTON);
 
 #define DEFAULT_STR N_("Click to select device…")
@@ -259,17 +257,15 @@ bluetooth_chooser_button_finalize (GObject *object)
 {
 	BluetoothChooserButton *button = BLUETOOTH_CHOOSER_BUTTON (object);
 
-	if (button->client != NULL) {
-		g_object_unref (button->client);
-		button->client = NULL;
-	}
+	g_clear_object (&button->client);
+
 	if (button->dialog != NULL) {
 		gtk_widget_destroy (button->dialog);
 		button->dialog = NULL;
 		button->chooser = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (bluetooth_chooser_button_parent_class)->finalize (object);
 }
 
 static void
@@ -318,8 +314,6 @@ bluetooth_chooser_button_class_init (BluetoothChooserButtonClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkButtonClass *button_class = GTK_BUTTON_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->finalize = bluetooth_chooser_button_finalize;
 	object_class->set_property = bluetooth_chooser_button_set_property;
 	object_class->get_property = bluetooth_chooser_button_get_property;
