@@ -21,15 +21,12 @@
  *
  */
 
-#ifndef __BLUETOOTH_CLIENT_PRIVATE_H
-#define __BLUETOOTH_CLIENT_PRIVATE_H
+#pragma once
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <bluetooth-enums.h>
 
-G_BEGIN_DECLS
-
 typedef void (*BluetoothClientSetupFunc) (BluetoothClient *client,
 					  const GError    *error,
 					  const char      *device_path);
@@ -45,6 +42,16 @@ gboolean bluetooth_client_setup_device_finish (BluetoothClient  *client,
 					       char            **path,
 					       GError          **error);
 
+void bluetooth_client_cancel_setup_device (BluetoothClient     *client,
+					   const char          *path,
+					   GCancellable        *cancellable,
+					   GAsyncReadyCallback  callback,
+					   gpointer             user_data);
+gboolean bluetooth_client_cancel_setup_device_finish (BluetoothClient *client,
+						      GAsyncResult     *res,
+						      char            **path,
+						      GError          **error);
+
 gboolean bluetooth_client_set_trusted(BluetoothClient *client,
 					const char *device, gboolean trusted);
 
@@ -57,7 +64,3 @@ void bluetooth_client_dump_device (GtkTreeModel *model,
 gboolean bluetooth_client_get_connectable(const char **uuids);
 
 GDBusProxy *_bluetooth_client_get_default_adapter (BluetoothClient *client);
-
-G_END_DECLS
-
-#endif /* __BLUETOOTH_CLIENT_PRIVATE_H */
