@@ -132,22 +132,20 @@ static gboolean iter_search(GtkTreeStore *store,
 	return found;
 }
 
-static gboolean compare_path(GtkTreeStore *store,
-					GtkTreeIter *iter, gpointer user_data)
+static gboolean
+compare_path (GtkTreeStore *store,
+	      GtkTreeIter *iter,
+	      gpointer user_data)
 {
 	const gchar *path = user_data;
-	GDBusProxy *object;
-	gboolean found = FALSE;
+	g_autoptr(GDBusProxy) object = NULL;
 
-	gtk_tree_model_get(GTK_TREE_MODEL(store), iter,
-					BLUETOOTH_COLUMN_PROXY, &object, -1);
+	gtk_tree_model_get (GTK_TREE_MODEL(store), iter,
+			    BLUETOOTH_COLUMN_PROXY, &object,
+			    -1);
 
-	if (object != NULL) {
-		found = g_str_equal(path, g_dbus_proxy_get_object_path(object));
-		g_object_unref(object);
-	}
-
-	return found;
+	return (object != NULL &&
+		g_str_equal (path, g_dbus_proxy_get_object_path (object)));
 }
 
 static gboolean
@@ -156,22 +154,19 @@ compare_address (GtkTreeStore *store,
 		 gpointer user_data)
 {
 	const char *address = user_data;
-	char *tmp_address;
-	gboolean found = FALSE;
+	g_autofree char *tmp_address = NULL;
 
 	gtk_tree_model_get (GTK_TREE_MODEL(store), iter,
 			    BLUETOOTH_COLUMN_ADDRESS, &tmp_address, -1);
-	found = g_str_equal (address, tmp_address);
-	g_free (tmp_address);
-
-	return found;
+	return (g_strcmp0 (address, tmp_address) == 0);
 }
 
 static gboolean
 get_iter_from_path (GtkTreeStore *store,
-		    GtkTreeIter *iter,
-		    const char *path)
+		    GtkTreeIter  *iter,
+		    const char   *path)
 {
+	g_return_val_if_fail (path != NULL, FALSE);
 	return iter_search(store, iter, NULL, compare_path, (gpointer) path);
 }
 
@@ -180,6 +175,7 @@ get_iter_from_proxy(GtkTreeStore *store,
 		    GtkTreeIter *iter,
 		    GDBusProxy *proxy)
 {
+	g_return_val_if_fail (proxy != NULL, FALSE);
 	return iter_search(store, iter, NULL, compare_path,
 			   (gpointer) g_dbus_proxy_get_object_path (proxy));
 }
@@ -192,6 +188,9 @@ get_iter_from_address (GtkTreeStore *store,
 {
 	GtkTreeIter parent_iter;
 
+	g_return_val_if_fail (address != NULL, FALSE);
+	g_return_val_if_fail (adapter != NULL, FALSE);
+
 	if (get_iter_from_proxy (store, &parent_iter, adapter) == FALSE)
 		return FALSE;
 
@@ -468,30 +467,49 @@ device_removed (const char      *path,
 	}
 }
 
-static gboolean
+static void
+adapter_set_powered_cb (GDBusProxy *proxy,
+			GAsyncResult *res,
+			gpointer      user_data)
+{
+	g_autoptr(GError) error = NULL;
+	g_autoptr(GVariant) ret = NULL;
+
+	ret = g_dbus_proxy_call_finish (proxy, res, &error);
+	if (!ret) {
+		g_debug ("Error setting property 'Powered' on interface org.bluez.Adapter1: %s (%s, %d)",
+			 error->message, g_quark_to_string (error->domain), error->code);
+	}
+}
+
+static void
 adapter_set_powered (BluetoothClient *client,
 		     const char *path,
 		     gboolean powered)
 {
 	BluetoothClientPrivate *priv = BLUETOOTH_CLIENT_GET_PRIVATE(client);
-	GObject *adapter;
+	g_autoptr(GObject) adapter = NULL;
 	GtkTreeIter iter;
+	GVariant *variant;
 
-	g_return_val_if_fail (BLUETOOTH_IS_CLIENT (client), FALSE);
+	g_return_if_fail (BLUETOOTH_IS_CLIENT (client));
 
 	if (get_iter_from_path (priv->store, &iter, path) == FALSE)
-		return FALSE;
+		return;
 
 	gtk_tree_model_get (GTK_TREE_MODEL (priv->store), &iter,
 			    BLUETOOTH_COLUMN_PROXY, &adapter, -1);
 
 	if (adapter == NULL)
-		return FALSE;
+		return;
 
-	g_object_set (adapter, "powered", powered, NULL);
-	g_object_unref (adapter);
-
-	return TRUE;
+	variant = g_variant_new_boolean (powered);
+	g_dbus_proxy_call (G_DBUS_PROXY (adapter),
+			   "org.freedesktop.DBus.Properties.Set",
+			   g_variant_new ("(ssv)", "org.bluez.Adapter1", "Powered", variant),
+			   G_DBUS_CALL_FLAGS_NONE,
+			   -1,
+			   NULL, (GAsyncReadyCallback) adapter_set_powered_cb, client);
 }
 
 static void
@@ -954,86 +972,32 @@ _bluetooth_client_get_default_adapter_name (BluetoothClient *self)
 	return ret;
 }
 
-/**
- * _bluetooth_client_set_discoverable:
- * @client: a #BluetoothClient object
- * @discoverable: whether the device should be discoverable
- *
- * Sets the default adapter's discoverable status.
- *
- * Return value: Whether setting the state on the default adapter was successful.
- **/
-static gboolean
-_bluetooth_client_set_discoverable (BluetoothClient *client,
-				    gboolean discoverable)
-{
-	BluetoothClientPrivate *priv = BLUETOOTH_CLIENT_GET_PRIVATE (client);
-	GtkTreePath *path;
-	GObject *adapter;
-	GtkTreeIter iter;
-
-	g_return_val_if_fail (BLUETOOTH_IS_CLIENT (client), FALSE);
-
-	if (priv->default_adapter == NULL)
-		return FALSE;
-
-	path = gtk_tree_row_reference_get_path (priv->default_adapter);
-	gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->store), &iter, path);
-	gtk_tree_model_get (GTK_TREE_MODEL (priv->store), &iter,
-                            BLUETOOTH_COLUMN_PROXY, &adapter, -1);
-        gtk_tree_path_free (path);
-
-	if (adapter == NULL)
-		return FALSE;
-
-	if (discoverable) {
-		g_object_set (adapter,
-			      "discoverable", discoverable,
-			      "discoverable-timeout", 0,
-			      NULL);
-	} else {
-		/* Work-around race in bluetoothd which would reset the discoverable
-		 * flag if a timeout change was requested before discoverable finished
-		 * being set to off:
-		 * https://bugzilla.redhat.com/show_bug.cgi?id=1602985 */
-		g_object_set (adapter,
-			      "discoverable", FALSE,
-			      NULL);
-	}
-	g_object_unref (adapter);
-
-	return TRUE;
-}
-
 static void
 _bluetooth_client_set_default_adapter_discovering (BluetoothClient *client,
 						   gboolean         discovering,
 						   gboolean         discoverable)
 {
 	BluetoothClientPrivate *priv = BLUETOOTH_CLIENT_GET_PRIVATE (client);
-	GDBusProxy *adapter;
+	g_autoptr(GDBusProxy) adapter = NULL;
 	GVariantBuilder builder;
 
 	adapter = _bluetooth_client_get_default_adapter (client);
 	if (adapter == NULL)
 		return;
 
-	g_variant_builder_init (&builder, G_VARIANT_TYPE_VARDICT);
-	g_variant_builder_add (&builder, "{sv}",
-			       "Discoverable", g_variant_new_boolean (discoverable));
-	if (!adapter1_call_set_discovery_filter_sync (ADAPTER1 (adapter),
-						      g_variant_builder_end (&builder), NULL, NULL)) {
-		/* BlueZ too old? */
-		_bluetooth_client_set_discoverable (client, discoverable);
+	if (discovering) {
+		g_variant_builder_init (&builder, G_VARIANT_TYPE_VARDICT);
+		g_variant_builder_add (&builder, "{sv}",
+				       "Discoverable", g_variant_new_boolean (discoverable));
+		adapter1_call_set_discovery_filter_sync (ADAPTER1 (adapter),
+							 g_variant_builder_end (&builder), NULL, NULL);
 	}
 
 	priv->discovery_started = discovering;
 	if (discovering)
-		adapter1_call_start_discovery_sync (ADAPTER1 (adapter), NULL, NULL);
+		adapter1_call_start_discovery (ADAPTER1 (adapter), NULL, NULL, NULL);
 	else
-		adapter1_call_stop_discovery_sync (ADAPTER1 (adapter), NULL, NULL);
-
-	g_object_unref(adapter);
+		adapter1_call_stop_discovery (ADAPTER1 (adapter), NULL, NULL, NULL);
 }
 
 static gboolean
@@ -1356,9 +1320,9 @@ typedef struct {
 } CreateDeviceData;
 
 static void
-device_pair_callback (GDBusProxy         *proxy,
-		      GAsyncResult       *res,
-		      GSimpleAsyncResult *simple)
+device_pair_callback (GDBusProxy   *proxy,
+		      GAsyncResult *res,
+		      GTask        *task)
 {
 	GError *error = NULL;
 
@@ -1366,43 +1330,42 @@ device_pair_callback (GDBusProxy         *proxy,
 		g_debug ("Pair() failed for %s: %s",
 			 g_dbus_proxy_get_object_path (proxy),
 			 error->message);
-		g_simple_async_result_take_error (simple, error);
+		g_task_return_error (task, error);
 	} else {
-		g_simple_async_result_set_op_res_gboolean (simple, TRUE);
+		g_task_return_boolean (task, TRUE);
 	}
-
-	g_simple_async_result_complete_in_idle (simple);
-
-	g_object_unref (simple);
+	g_object_unref (task);
 }
 
+/**
+ * bluetooth_client_setup_device_finish:
+ * @client:
+ * @res:
+ * @path: (out):
+ * @error:
+ */
 gboolean
 bluetooth_client_setup_device_finish (BluetoothClient  *client,
 				      GAsyncResult     *res,
 				      char            **path,
 				      GError          **error)
 {
-	GSimpleAsyncResult *simple;
+	GTask *task;
 	char *object_path;
 	gboolean ret;
 
 	g_return_val_if_fail (path != NULL, FALSE);
 
-	simple = (GSimpleAsyncResult *) res;
+	task = G_TASK (res);
 
-	g_warn_if_fail (g_simple_async_result_get_source_tag (simple) == bluetooth_client_setup_device);
+	g_warn_if_fail (g_task_get_source_tag (task) == bluetooth_client_setup_device);
 
-	ret = g_simple_async_result_get_op_res_gboolean (simple);
-	object_path = g_strdup (g_object_get_data (G_OBJECT (res), "device-object-path"));
+	ret = g_task_propagate_boolean (task, error);
+	object_path = g_strdup (g_task_get_task_data (task));
 	*path = object_path;
 	g_debug ("bluetooth_client_setup_device_finish() %s (path: %s)",
 		 ret ? "success" : "failure", object_path);
-
-	if (ret)
-		return TRUE;
-
-	g_simple_async_result_propagate_error (simple, error);
-	return FALSE;
+	return ret;
 }
 
 void
@@ -1414,28 +1377,26 @@ bluetooth_client_setup_device (BluetoothClient          *client,
 			       gpointer                  user_data)
 {
 	BluetoothClientPrivate *priv = BLUETOOTH_CLIENT_GET_PRIVATE(client);
-	GSimpleAsyncResult *simple;
-	GDBusProxy *device;
+	GTask *task;
+	g_autoptr(GDBusProxy) device = NULL;
 	GtkTreeIter iter, adapter_iter;
 	gboolean paired;
-	GError *err = NULL;
 
 	g_return_if_fail (BLUETOOTH_IS_CLIENT (client));
+	g_return_if_fail (path != NULL);
 
-	simple = g_simple_async_result_new (G_OBJECT (client),
-					    callback,
-					    user_data,
-					    bluetooth_client_setup_device);
-	g_simple_async_result_set_check_cancellable (simple, cancellable);
-	g_object_set_data_full (G_OBJECT (simple), "device-object-path",
-				g_strdup (path), (GDestroyNotify) g_free);
+	task = g_task_new (G_OBJECT (client),
+			   cancellable,
+			   callback,
+			   user_data);
+	g_task_set_source_tag (task, bluetooth_client_setup_device);
+	g_task_set_task_data (task, g_strdup (path), (GDestroyNotify) g_free);
 
 	if (get_iter_from_path (priv->store, &iter, path) == FALSE) {
-		g_simple_async_result_set_error (simple, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-						 "Device with object path %s does not exist",
-						 path);
-		g_simple_async_result_complete_in_idle (simple);
-		g_object_unref (simple);
+		g_task_return_new_error (task, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+					 "Device with object path %s does not exist",
+					 path);
+		g_object_unref (task);
 		return;
 	}
 
@@ -1446,6 +1407,7 @@ bluetooth_client_setup_device (BluetoothClient          *client,
 	if (paired != FALSE &&
 	    gtk_tree_model_iter_parent (GTK_TREE_MODEL(priv->store), &adapter_iter, &iter)) {
 		GDBusProxy *adapter;
+		g_autoptr(GError) err = NULL;
 
 		gtk_tree_model_get (GTK_TREE_MODEL(priv->store), &adapter_iter,
 				    BLUETOOTH_COLUMN_PROXY, &adapter,
@@ -1453,10 +1415,8 @@ bluetooth_client_setup_device (BluetoothClient          *client,
 		adapter1_call_remove_device_sync (ADAPTER1 (adapter),
 						  path,
 						  NULL, &err);
-		if (err != NULL) {
+		if (err != NULL)
 			g_warning ("Failed to remove device: %s", err->message);
-			g_error_free (err);
-		}
 		g_object_unref (adapter);
 	}
 
@@ -1464,14 +1424,100 @@ bluetooth_client_setup_device (BluetoothClient          *client,
 		device1_call_pair (DEVICE1(device),
 				   cancellable,
 				   (GAsyncReadyCallback) device_pair_callback,
-				   simple);
+				   task);
 	} else {
-		g_simple_async_result_set_op_res_gboolean (simple, TRUE);
-		g_simple_async_result_complete_in_idle (simple);
-		g_object_unref (simple);
+		g_task_return_boolean (task, TRUE);
+		g_object_unref (task);
+	}
+}
+
+/**
+ * bluetooth_client_cancel_setup_device_finish:
+ * @client:
+ * @res:
+ * @path: (out):
+ * @error:
+ */
+gboolean
+bluetooth_client_cancel_setup_device_finish (BluetoothClient  *client,
+					     GAsyncResult     *res,
+					     char            **path,
+					     GError          **error)
+{
+	GTask *task;
+	char *object_path;
+	gboolean ret;
+
+	g_return_val_if_fail (path != NULL, FALSE);
+
+	task = G_TASK (res);
+
+	g_warn_if_fail (g_task_get_source_tag (task) == bluetooth_client_cancel_setup_device);
+
+	ret = g_task_propagate_boolean (task, error);
+	object_path = g_strdup (g_task_get_task_data (task));
+	*path = object_path;
+	g_debug ("bluetooth_client_cancel_setup_device_finish() %s (path: %s)",
+		 ret ? "success" : "failure", object_path);
+	return ret;
+}
+
+static void
+device_cancel_pairing_callback (GDBusProxy   *proxy,
+				GAsyncResult *res,
+				GTask        *task)
+{
+	GError *error = NULL;
+
+	if (device1_call_cancel_pairing_finish (DEVICE1(proxy), res, &error) == FALSE) {
+		g_debug ("CancelPairing() failed for %s: %s",
+			 g_dbus_proxy_get_object_path (proxy),
+			 error->message);
+		g_task_return_error (task, error);
+	} else {
+		g_task_return_boolean (task, TRUE);
+	}
+	g_object_unref (task);
+}
+
+void
+bluetooth_client_cancel_setup_device (BluetoothClient          *client,
+				      const char               *path,
+				      GCancellable             *cancellable,
+				      GAsyncReadyCallback       callback,
+				      gpointer                  user_data)
+{
+	BluetoothClientPrivate *priv = BLUETOOTH_CLIENT_GET_PRIVATE(client);
+	GTask *task;
+	g_autoptr(GDBusProxy) device = NULL;
+	GtkTreeIter iter;
+
+	g_return_if_fail (BLUETOOTH_IS_CLIENT (client));
+	g_return_if_fail (path != NULL);
+
+	task = g_task_new (G_OBJECT (client),
+			   cancellable,
+			   callback,
+			   user_data);
+	g_task_set_source_tag (task, bluetooth_client_cancel_setup_device);
+	g_task_set_task_data (task, g_strdup (path), (GDestroyNotify) g_free);
+
+	if (get_iter_from_path (priv->store, &iter, path) == FALSE) {
+		g_task_return_new_error (task, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+					 "Device with object path %s does not exist",
+					 path);
+		g_object_unref (task);
+		return;
 	}
 
-	g_object_unref (device);
+	gtk_tree_model_get (GTK_TREE_MODEL(priv->store), &iter,
+			    BLUETOOTH_COLUMN_PROXY, &device,
+			    -1);
+
+	device1_call_cancel_pairing (DEVICE1(device),
+				     cancellable,
+				     (GAsyncReadyCallback) device_cancel_pairing_callback,
+				     task);
 }
 
 gboolean
@@ -1522,52 +1568,48 @@ bluetooth_client_get_device (BluetoothClient *client,
 }
 
 static void
-connect_callback (GDBusProxy         *proxy,
-		  GAsyncResult       *res,
-		  GSimpleAsyncResult *simple)
+connect_callback (GDBusProxy   *proxy,
+		  GAsyncResult *res,
+		  GTask        *task)
 {
 	gboolean retval;
 	GError *error = NULL;
 
-	retval = device1_call_connect_finish (DEVICE1(proxy), res, &error);
+	retval = device1_call_connect_finish (DEVICE1 (proxy), res, &error);
 	if (retval == FALSE) {
 		g_debug ("Connect failed for %s: %s",
 			 g_dbus_proxy_get_object_path (proxy), error->message);
-		g_simple_async_result_take_error (simple, error);
+		g_task_return_error (task, error);
 	} else {
 		g_debug ("Connect succeeded for %s",
 			 g_dbus_proxy_get_object_path (proxy));
-		g_simple_async_result_set_op_res_gboolean (simple, retval);
+		g_task_return_boolean (task, retval);
 	}
 
-	g_simple_async_result_complete_in_idle (simple);
-
-	g_object_unref (simple);
+	g_object_unref (task);
 }
 
 static void
 disconnect_callback (GDBusProxy   *proxy,
 		     GAsyncResult *res,
-		     GSimpleAsyncResult *simple)
+		     GTask        *task)
 {
 	gboolean retval;
 	GError *error = NULL;
 
-	retval = device1_call_disconnect_finish (DEVICE1(proxy), res, &error);
+	retval = device1_call_disconnect_finish (DEVICE1 (proxy), res, &error);
 	if (retval == FALSE) {
 		g_debug ("Disconnect failed for %s: %s",
 			 g_dbus_proxy_get_object_path (proxy),
 			 error->message);
-		g_simple_async_result_take_error (simple, error);
+		g_task_return_error (task, error);
 	} else {
 		g_debug ("Disconnect succeeded for %s",
 			 g_dbus_proxy_get_object_path (proxy));
-		g_simple_async_result_set_op_res_gboolean (simple, retval);
+		g_task_return_boolean (task, retval);
 	}
 
-	g_simple_async_result_complete_in_idle (simple);
-
-	g_object_unref (simple);
+	g_object_unref (task);
 }
 
 /**
@@ -1593,38 +1635,41 @@ bluetooth_client_connect_service (BluetoothClient     *client,
 {
 	BluetoothClientPrivate *priv = BLUETOOTH_CLIENT_GET_PRIVATE(client);
 	GtkTreeIter iter;
-	GSimpleAsyncResult *simple;
-	GDBusProxy *device;
+	GTask *task;
+	g_autoptr(GDBusProxy) device = NULL;
 
 	g_return_if_fail (BLUETOOTH_IS_CLIENT (client));
 	g_return_if_fail (path != NULL);
 
-	if (get_iter_from_path (priv->store, &iter, path) == FALSE)
+	task = g_task_new (G_OBJECT (client),
+			   cancellable,
+			   callback,
+			   user_data);
+	g_task_set_source_tag (task, bluetooth_client_connect_service);
+
+	if (get_iter_from_path (priv->store, &iter, path) == FALSE) {
+		g_task_return_new_error (task, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+					 "Device with object path %s does not exist",
+					 path);
+		g_object_unref (task);
 		return;
+	}
 
 	gtk_tree_model_get (GTK_TREE_MODEL(priv->store), &iter,
 			    BLUETOOTH_COLUMN_PROXY, &device,
 			    -1);
 
-	simple = g_simple_async_result_new (G_OBJECT (client),
-					    callback,
-					    user_data,
-					    bluetooth_client_connect_service);
-	g_simple_async_result_set_check_cancellable (simple, cancellable);
-
 	if (connect) {
 		device1_call_connect (DEVICE1(device),
 				      cancellable,
 				      (GAsyncReadyCallback) connect_callback,
-				      simple);
+				      task);
 	} else {
 		device1_call_disconnect (DEVICE1(device),
 					 cancellable,
 					 (GAsyncReadyCallback) disconnect_callback,
-					 simple);
+					 task);
 	}
-
-	g_object_unref (device);
 }
 
 /**
@@ -1642,16 +1687,13 @@ bluetooth_client_connect_service_finish (BluetoothClient *client,
 					 GAsyncResult    *res,
 					 GError         **error)
 {
-	GSimpleAsyncResult *simple;
+	GTask *task;
 
-	simple = (GSimpleAsyncResult *) res;
+	task = G_TASK (res);
 
-	g_warn_if_fail (g_simple_async_result_get_source_tag (simple) == bluetooth_client_connect_service);
+	g_warn_if_fail (g_task_get_source_tag (task) == bluetooth_client_connect_service);
 
-	if (g_simple_async_result_get_op_res_gboolean (simple))
-		return TRUE;
-	g_simple_async_result_propagate_error (simple, error);
-	return FALSE;
+	return g_task_propagate_boolean (task, error);
 }
 
 #define BOOL_STR(x) (x ? "True" : "False")
