@@ -21,15 +21,12 @@
  *
  */
 
-#ifndef __BLUETOOTH_CLIENT_H
-#define __BLUETOOTH_CLIENT_H
+#pragma once
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <bluetooth-enums.h>
 
-G_BEGIN_DECLS
-
 #define BLUETOOTH_TYPE_CLIENT (bluetooth_client_get_type())
 #define BLUETOOTH_CLIENT(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), \
 					BLUETOOTH_TYPE_CLIENT, BluetoothClient))
@@ -81,9 +78,3 @@ void bluetooth_client_connect_service (BluetoothClient     *client,
 gboolean bluetooth_client_connect_service_finish (BluetoothClient *client,
 						  GAsyncResult    *res,
 						  GError         **error);
-
-gboolean bluetooth_client_get_connectable(const char **uuids);
-
-G_END_DECLS
-
-#endif /* __BLUETOOTH_CLIENT_H */
