@@ -8,8 +8,6 @@
 
 #include <gtk/gtk.h>
 
-G_BEGIN_DECLS
-
 #define BLUETOOTH_TYPE_HDY_COLUMN (bluetooth_hdy_column_get_type())
 
 G_DECLARE_FINAL_TYPE (BluetoothHdyColumn, bluetooth_hdy_column, BLUETOOTH, HDY_COLUMN, GtkBin)
@@ -21,5 +19,3 @@ void bluetooth_hdy_column_set_maximum_width (BluetoothHdyColumn *self,
 gint bluetooth_hdy_column_get_linear_growth_width (BluetoothHdyColumn *self);
 void bluetooth_hdy_column_set_linear_growth_width (BluetoothHdyColumn *self,
                                                    gint                linear_growth_width);
-
-G_END_DECLS
