@@ -49,8 +49,10 @@ struct _BluetoothSettingsRowPrivate {
 	BluetoothType type;
 	gboolean connected;
 	char *name;
+	char *alias;
 	char *bdaddr;
 	gboolean legacy_pairing;
+	gint64 time_created;
 
 	gboolean pairing;
 };
@@ -63,9 +65,11 @@ enum {
 	PROP_TYPE,
 	PROP_CONNECTED,
 	PROP_NAME,
+	PROP_ALIAS,
 	PROP_ADDRESS,
 	PROP_PAIRING,
-	PROP_LEGACY_PAIRING
+	PROP_LEGACY_PAIRING,
+	PROP_TIME_CREATED
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE(BluetoothSettingsRow, bluetooth_settings_row, GTK_TYPE_LIST_BOX_ROW)
@@ -100,6 +104,8 @@ bluetooth_settings_row_init (BluetoothSettingsRow *self)
 				priv->status, "visible", G_BINDING_INVERT_BOOLEAN | G_BINDING_BIDIRECTIONAL);
 	g_object_bind_property (priv->spinner, "active",
 				priv->status, "visible", G_BINDING_INVERT_BOOLEAN | G_BINDING_BIDIRECTIONAL);
+
+	priv->time_created = g_get_monotonic_time();
 }
 
 static void
@@ -110,6 +116,7 @@ bluetooth_settings_row_finalize (GObject *object)
 
 	g_clear_object (&priv->proxy);
 	g_clear_pointer (&priv->name, g_free);
+	g_clear_pointer (&priv->alias, g_free);
 	g_clear_pointer (&priv->bdaddr, g_free);
 
 	G_OBJECT_CLASS(bluetooth_settings_row_parent_class)->finalize(object);
@@ -143,6 +150,9 @@ bluetooth_settings_row_get_property (GObject        *object,
 	case PROP_NAME:
 		g_value_set_string (value, priv->name);
 		break;
+	case PROP_ALIAS:
+		g_value_set_string (value, priv->alias);
+		break;
 	case PROP_ADDRESS:
 		g_value_set_string (value, priv->bdaddr);
 		break;
@@ -152,6 +162,9 @@ bluetooth_settings_row_get_property (GObject        *object,
 	case PROP_LEGACY_PAIRING:
 		g_value_set_boolean (value, priv->legacy_pairing);
 		break;
+	case PROP_TIME_CREATED:
+		g_value_set_int64 (value, priv->time_created);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
 		break;
@@ -168,7 +181,7 @@ update_row (BluetoothSettingsRow *self)
 				    bluetooth_type_to_string (priv->type));
 		gtk_widget_set_sensitive (GTK_WIDGET (self), FALSE);
 	} else {
-		gtk_label_set_text (GTK_LABEL (priv->label), priv->name);
+		gtk_label_set_text (GTK_LABEL (priv->label), priv->alias);
 		gtk_widget_set_sensitive (GTK_WIDGET (self), TRUE);
 	}
 }
@@ -208,6 +221,11 @@ bluetooth_settings_row_set_property (GObject        *object,
 		priv->name = g_value_dup_string (value);
 		update_row (self);
 		break;
+	case PROP_ALIAS:
+		g_free (priv->alias);
+		priv->alias = g_value_dup_string (value);
+		update_row (self);
+		break;
 	case PROP_ADDRESS:
 		g_free (priv->bdaddr);
 		priv->bdaddr = g_value_dup_string (value);
@@ -261,6 +279,10 @@ bluetooth_settings_row_class_init (BluetoothSettingsRowClass *klass)
 					 g_param_spec_string ("name", NULL,
 							      "Name",
 							      NULL, G_PARAM_READWRITE));
+	g_object_class_install_property (object_class, PROP_ALIAS,
+					 g_param_spec_string ("alias", NULL,
+							      "Alias",
+							      NULL, G_PARAM_READWRITE));
 	g_object_class_install_property (object_class, PROP_ADDRESS,
 					 g_param_spec_string ("address", NULL,
 							      "Address",
@@ -273,6 +295,10 @@ bluetooth_settings_row_class_init (BluetoothSettingsRowClass *klass)
 					 g_param_spec_boolean ("legacy-pairing", NULL,
 							      "Legacy pairing",
 							      FALSE, G_PARAM_READWRITE));
+	g_object_class_install_property (object_class, PROP_TIME_CREATED,
+					 g_param_spec_int64 ("time-created", NULL,
+							    "Time Created",
+							    G_MININT64, G_MAXINT64, 0, G_PARAM_READABLE));
 
 	/* Bind class to template */
 	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/bluetooth/bluetooth-settings-row.ui");
