@@ -22,14 +22,11 @@
  *
  */
 
-#ifndef __BLUETOOTH_UTILS_H
-#define __BLUETOOTH_UTILS_H
+#pragma once
 
 #include <gio/gio.h>
 #include <bluetooth-enums.h>
 
-G_BEGIN_DECLS
-
 /*
  * The profile UUID list is provided by the Bluetooth SIG:
  * https://www.bluetooth.com/specifications/assigned-numbers/service-discovery
@@ -61,6 +58,7 @@ G_BEGIN_DECLS
 #define BLUETOOTH_UUID_VDP_SOURCE	0x1303
 
 BluetoothType  bluetooth_class_to_type         (guint32 class);
+BluetoothType  bluetooth_appearance_to_type    (guint16 appearance);
 const gchar   *bluetooth_type_to_string        (guint type);
 const gchar   *bluetooth_type_to_filter_string (guint type);
 gboolean       bluetooth_verify_address        (const char *bdaddr);
@@ -68,7 +66,3 @@ const char    *bluetooth_uuid_to_string        (const char *uuid);
 
 void bluetooth_send_to_address (const char *address,
 				const char *alias);
-
-G_END_DECLS
-
-#endif /* __BLUETOOTH_UTILS_H */
